@@ -5,6 +5,7 @@ from canvasapi.comm_message import CommMessage
 from canvasapi.course import Course
 from canvasapi.course_epub_export import CourseEpubExport
 from canvasapi.current_user import CurrentUser
+from canvasapi.eportfolio import EPortfolio
 from canvasapi.exceptions import RequiredFieldMissing
 from canvasapi.file import File
 from canvasapi.folder import Folder
@@ -12,6 +13,7 @@ from canvasapi.group import Group, GroupCategory
 from canvasapi.paginated_list import PaginatedList
 from canvasapi.requester import Requester
 from canvasapi.section import Section
+from canvasapi.todo import Todo
 from canvasapi.user import User
 from canvasapi.util import combine_kwargs, get_institution_url, obj_or_id
 
@@ -343,28 +345,28 @@ class Canvas(object):
         )
         return PlannerOverride(self.__requester, response.json())
 
-    def create_poll(self, poll, **kwargs):
+    def create_poll(self, polls, **kwargs):
         """
         Create a new poll for the current user.
 
         :calls: `POST /api/v1/polls \
         <https://canvas.instructure.com/doc/api/polls.html#method.polling/polls.create>`_
 
-        :param poll: List of polls to create. `'question'` key is required.
-        :type poll: list of dict
+        :param polls: List of polls to create. `'question'` key is required.
+        :type polls: list of dict
         :rtype: :class:`canvasapi.poll.Poll`
         """
         from canvasapi.poll import Poll
 
         if (
-            isinstance(poll, list)
-            and isinstance(poll[0], dict)
-            and "question" in poll[0]
+            isinstance(polls, list)
+            and isinstance(polls[0], dict)
+            and "question" in polls[0]
         ):
-            kwargs["poll"] = poll
+            kwargs["polls"] = polls
         else:
             raise RequiredFieldMissing(
-                "Dictionary with key 'question' and is required."
+                "List of dictionaries each with key 'question' is required."
             )
 
         response = self.__requester.request(
@@ -770,6 +772,27 @@ class Canvas(object):
         """
         return CurrentUser(self.__requester)
 
+    def get_eportfolio(self, eportfolio, **kwargs):
+        """
+        Get an eportfolio by ID.
+
+        :param eportfolio: The object or ID of the eportfolio to retrieve.
+        :type eportfolio: :class: `canvasapi.eportfolio.EPortfolio` or int
+
+        :calls: `GET /api/v1/eportfolios/:id` \
+            `<https://canvas.instructure.com/doc/api/e_portfolios.html#method.eportfolios_api.show>`_
+
+        :rtype: :class:`canvasapi.eportfolio.EPortfolio`
+        """
+        eportfolio_id = obj_or_id(eportfolio, "eportfolio", (EPortfolio,))
+        response = self.__requester.request(
+            "GET",
+            "eportfolios/{}".format(eportfolio_id),
+            _kwargs=combine_kwargs(**kwargs),
+        )
+
+        return EPortfolio(self.__requester, response.json())
+
     def get_epub_exports(self, **kwargs):
         """
         Return a list of epub exports for the associated course.
@@ -1170,10 +1193,13 @@ class Canvas(object):
 
         :rtype: dict
         """
-        response = self.__requester.request(
-            "GET", "users/self/todo", _kwargs=combine_kwargs(**kwargs)
+        return PaginatedList(
+            Todo,
+            self.__requester,
+            "GET",
+            "users/self/todo",
+            _kwargs=combine_kwargs(**kwargs),
         )
-        return response.json()
 
     def get_upcoming_events(self, **kwargs):
         """
